DetectedMicrohaplotypes
DetectedMicrohaplotypes.RdThe microhaplotypes detected in a targeted amplicon analysis.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
bioinformatics_run_id: The index into bioinformatics_run_info list.library_samples: A list of the microhaplotypes detected for all samples with a list for each target.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
bioinformatics_run_idThe index into bioinformatics_run_info list.
library_samplesA list of the microhaplotypes detected for all samples with a list for each target.
extrasAdditional properties not explicitly defined in the schema.
Methods
DetectedMicrohaplotypes$new()
Create a new instance.
Usage
DetectedMicrohaplotypes$new(
bioinformatics_run_id = NULL,
library_samples = list(),
extras = list()
)DetectedMicrohaplotypes$validate()
Validate the current instance against schema-derived constraints.
DetectedMicrohaplotypes$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().