PmoGenerationMethod
PmoGenerationMethod.RdInformation about how a PMO was generated.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
program_name: The name of the program.program_version: The version of program, should be in the format of v[MAJOR].[MINOR].[PATCH].extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
program_nameThe name of the program.
program_versionThe version of program, should be in the format of v[MAJOR].[MINOR].[PATCH].
extrasAdditional properties not explicitly defined in the schema.
Methods
PmoGenerationMethod$new()
Create a new instance.
Usage
PmoGenerationMethod$new(
program_name = NA_character_,
program_version = NA_character_,
extras = list()
)PmoGenerationMethod$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().