Count the number of unique targets in each panel
pmo_count_targets_per_panel.RdCount the number of unique targets in each panel
Examples
p <- read_pmo(
system.file("extdata", "example_full_pmo.json.gz", package = "pmotoolsr"))
pmo_count_targets_per_panel(p)
#> # A tibble: 1 × 2
#> panel_name panel_target_count
#> <chr> <int>
#> 1 heomev1 100