BioMethod
BioMethod.RdBioinformatics methodology description with info on program, version, and arguments different from the default.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
additional_argument: Any additional arguments that differ from the default arguments.program: Name of the program used for this portion of the pipeline.program_description: A short description of what this method does.program_url: A url pointing to code base of a program, e.g. a github link.program_version: The version of program, should be in the format of v[MAJOR].[MINOR].[PATCH].extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
additional_argumentAny additional arguments that differ from the default arguments.
programName of the program used for this portion of the pipeline.
program_descriptionA short description of what this method does.
program_urlA url pointing to code base of a program, e.g. a github link.
program_versionThe version of program, should be in the format of v[MAJOR].[MINOR].[PATCH].
extrasAdditional properties not explicitly defined in the schema.
Methods
BioMethod$new()
Create a new instance.
Arguments
additional_argumentAny additional arguments that differ from the default arguments.
programName of the program used for this portion of the pipeline.
program_descriptionA short description of what this method does.
program_urlA url pointing to code base of a program, e.g. a github link.
program_versionThe version of program, should be in the format of v[MAJOR].[MINOR].[PATCH].
extrasAdditional properties not explicitly defined in the schema.
BioMethod$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().