BioinformaticsMethodInfo
BioinformaticsMethodInfo.RdThe targeted amplicon bioinformatics methods used to generate the microhaplotype data in this PMO.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
methods: Methodology used to generate the microhaplotype data stored in this PMO, e.g. demultiplexing method, denosing method, or a pipeline method that ties all th steps together.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
methodsMethodology used to generate the microhaplotype data stored in this PMO, e.g. demultiplexing method, denosing method, or a pipeline method that ties all th steps together.
extrasAdditional properties not explicitly defined in the schema.
Methods
BioinformaticsMethodInfo$new()
Create a new instance.
Usage
BioinformaticsMethodInfo$new(methods = list(), extras = list())BioinformaticsMethodInfo$validate()
Validate the current instance against schema-derived constraints.
BioinformaticsMethodInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().