BioinformaticsRunInfo
BioinformaticsRunInfo.RdInformation about the pipeline run that generated microhaplotype_detected and reads_by_stage.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
bioinformatics_methods_id: The index into the bioinformatics_methods_info list.bioinformatics_run_name: A name to for this run, needs to be unique to each run.run_date: The date when the run was done, should be YYYY-MM-DD.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
bioinformatics_methods_idThe index into the bioinformatics_methods_info list.
bioinformatics_run_nameA name to for this run, needs to be unique to each run.
run_dateThe date when the run was done, should be YYYY-MM-DD.
extrasAdditional properties not explicitly defined in the schema.
Methods
BioinformaticsRunInfo$new()
Create a new instance.
Usage
BioinformaticsRunInfo$new(
bioinformatics_methods_id = NA_real_,
bioinformatics_run_name = NA_character_,
run_date = NULL,
extras = list()
)BioinformaticsRunInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().