DetectedMicrohaplotypesForSample
DetectedMicrohaplotypesForSample.RdMicrohaplotypes detected for a sample for all targets.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
library_sample_id: The index into the library_sample_info list.target_results: A list of the microhaplotypes detected for a list of targets.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
library_sample_idThe index into the library_sample_info list.
target_resultsA list of the microhaplotypes detected for a list of targets.
extrasAdditional properties not explicitly defined in the schema.
Methods
DetectedMicrohaplotypesForSample$new()
Create a new instance.
Usage
DetectedMicrohaplotypesForSample$new(
library_sample_id = NA_real_,
target_results = list(),
extras = list()
)DetectedMicrohaplotypesForSample$validate()
Validate the current instance against schema-derived constraints.
DetectedMicrohaplotypesForSample$to_list()
Convert the object to a plain R list using in-memory values.
DetectedMicrohaplotypesForSample$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().