GenomeInfo
GenomeInfo.RdInformation on a genome.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
chromosomes: A list of the chromosomes/contigs found within this genome.genome_version: The genome version.gff_url: A link to the where this genome's annotation file could be downloaded.name: Name of the genome.taxon_id: The NCBI taxonomy number, can be a list of values if it's a genome file that has been created by combining gnomes from different species.url: A link to the where this genome file could be downloaded.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
chromosomesA list of the chromosomes/contigs found within this genome.
genome_versionThe genome version.
gff_urlA link to the where this genome's annotation file could be downloaded.
nameName of the genome.
taxon_idThe NCBI taxonomy number, can be a list of values if it's a genome file that has been created by combining gnomes from different species.
urlA link to the where this genome file could be downloaded.
extrasAdditional properties not explicitly defined in the schema.
Methods
GenomeInfo$new()
Create a new instance.
Usage
GenomeInfo$new(
chromosomes = NULL,
genome_version = NA_character_,
gff_url = NULL,
name = NA_character_,
taxon_id = numeric(),
url = NA_character_,
extras = list()
)Arguments
chromosomesA list of the chromosomes/contigs found within this genome.
genome_versionThe genome version.
gff_urlA link to the where this genome's annotation file could be downloaded.
nameName of the genome.
taxon_idThe NCBI taxonomy number, can be a list of values if it's a genome file that has been created by combining gnomes from different species.
urlA link to the where this genome file could be downloaded.
extrasAdditional properties not explicitly defined in the schema.
GenomeInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().