MaskingInfo
MaskingInfo.RdInformation about a subsegment of the sequence that should be masked.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
masking_generation_description: A description of how the masking information was generated.replacement_size: The size of replacement mask.seq_segment_size: The size of the masking.seq_start: The start of the masking.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
masking_generation_descriptionA description of how the masking information was generated.
replacement_sizeThe size of replacement mask.
seq_segment_sizeThe size of the masking.
seq_startThe start of the masking.
extrasAdditional properties not explicitly defined in the schema.
Methods
MaskingInfo$new()
Create a new instance.
Usage
MaskingInfo$new(
masking_generation_description = NULL,
replacement_size = NA_real_,
seq_segment_size = NA_real_,
seq_start = NA_real_,
extras = list()
)MaskingInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().