MicrohaplotypeForTarget
MicrohaplotypeForTarget.RdMicrohaplotype detected for a specific target.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
mhap_id: The index for a microhaplotype for a target in the representative_microhaplotypes list, e.g. representative_microhaplotypes[mhaps_target_id][mhap_id].reads: The read count for this microhaplotype.umis: The unique molecular identifier (umi) count for this microhaplotype.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
mhap_idThe index for a microhaplotype for a target in the representative_microhaplotypes list, e.g. representative_microhaplotypes[mhaps_target_id][mhap_id].
readsThe read count for this microhaplotype.
umisThe unique molecular identifier (umi) count for this microhaplotype.
extrasAdditional properties not explicitly defined in the schema.
Methods
MicrohaplotypeForTarget$new()
Create a new instance.
Usage
MicrohaplotypeForTarget$new(
mhap_id = NA_real_,
reads = NA_real_,
umis = NULL,
extras = list()
)Arguments
mhap_idThe index for a microhaplotype for a target in the representative_microhaplotypes list, e.g. representative_microhaplotypes[mhaps_target_id][mhap_id].
readsThe read count for this microhaplotype.
umisThe unique molecular identifier (umi) count for this microhaplotype.
extrasAdditional properties not explicitly defined in the schema.
MicrohaplotypeForTarget$validate()
Validate the current instance against schema-derived constraints.
MicrohaplotypeForTarget$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().