PmoHeader
PmoHeader.RdInformation on the PMO file itself.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
creation_date: The date of when the PMO file was created or modified, should be YYYY-MM-DD.generation_method: The generation method to create this PMO.pmo_version: The version of the PMO file, should be in the format of v[MAJOR].[MINOR].[PATCH].extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
creation_dateThe date of when the PMO file was created or modified, should be YYYY-MM-DD.
generation_methodThe generation method to create this PMO.
pmo_versionThe version of the PMO file, should be in the format of v[MAJOR].[MINOR].[PATCH].
extrasAdditional properties not explicitly defined in the schema.
Methods
PmoHeader$new()
Create a new instance.
Arguments
creation_dateThe date of when the PMO file was created or modified, should be YYYY-MM-DD.
generation_methodThe generation method to create this PMO.
pmo_versionThe version of the PMO file, should be in the format of v[MAJOR].[MINOR].[PATCH].
extrasAdditional properties not explicitly defined in the schema.
PmoHeader$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().