PrimerInfo
PrimerInfo.RdInformation on a primer sequence.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
location: What the intended genomic location of the primer is.seq: The sequence.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
locationWhat the intended genomic location of the primer is.
seqThe sequence.
extrasAdditional properties not explicitly defined in the schema.
Methods
PrimerInfo$new()
Create a new instance.
Usage
PrimerInfo$new(location = NULL, seq = NA_character_, extras = list())PrimerInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().