ProjectInfo
ProjectInfo.RdInformation on a project underwhich a collection of specimens belong to.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
BioProject_accession: An SRA bioproject accession e.g. PRJNA33823.project_collector_chief_scientist: Can be collection of names separated by a semicolon if multiple people involved or can just be the name of the primary person managing the specimen.project_contributors: A list of collaborators who contributed to this project.project_description: A short description of the project.project_name: A name for the project, should be unique if multiple projects listed.project_type: The type of project conducted, e.g. TES vs surveillance vs transmission.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
BioProject_accessionAn SRA bioproject accession e.g. PRJNA33823.
project_collector_chief_scientistCan be collection of names separated by a semicolon if multiple people involved or can just be the name of the primary person managing the specimen.
project_contributorsA list of collaborators who contributed to this project.
project_descriptionA short description of the project.
project_nameA name for the project, should be unique if multiple projects listed.
project_typeThe type of project conducted, e.g. TES vs surveillance vs transmission.
extrasAdditional properties not explicitly defined in the schema.
Methods
ProjectInfo$new()
Create a new instance.
Usage
ProjectInfo$new(
BioProject_accession = NULL,
project_collector_chief_scientist = NULL,
project_contributors = NULL,
project_description = NA_character_,
project_name = NA_character_,
project_type = NULL,
extras = list()
)Arguments
BioProject_accessionAn SRA bioproject accession e.g. PRJNA33823.
project_collector_chief_scientistCan be collection of names separated by a semicolon if multiple people involved or can just be the name of the primary person managing the specimen.
project_contributorsA list of collaborators who contributed to this project.
project_descriptionA short description of the project.
project_nameA name for the project, should be unique if multiple projects listed.
project_typeThe type of project conducted, e.g. TES vs surveillance vs transmission.
extrasAdditional properties not explicitly defined in the schema.
ProjectInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().