ProteinVariant
ProteinVariant.RdInformation on a variant in protein sequence.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
alternative_gene_name: An alternative gene name.codon_genomic_location: The position within the genomic sequence of the codon.gene_name: An identifier of the gene, if any, is being covered with this targeted.protein_location: The position within the protein, the chromosome in this case would be the transcript name.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
alternative_gene_nameAn alternative gene name.
codon_genomic_locationThe position within the genomic sequence of the codon.
gene_nameAn identifier of the gene, if any, is being covered with this targeted.
protein_locationThe position within the protein, the chromosome in this case would be the transcript name.
extrasAdditional properties not explicitly defined in the schema.
Methods
ProteinVariant$new()
Create a new instance.
Usage
ProteinVariant$new(
alternative_gene_name = NULL,
codon_genomic_location = NULL,
gene_name = NULL,
protein_location = NULL,
extras = list()
)Arguments
alternative_gene_nameAn alternative gene name.
codon_genomic_locationThe position within the genomic sequence of the codon.
gene_nameAn identifier of the gene, if any, is being covered with this targeted.
protein_locationThe position within the protein, the chromosome in this case would be the transcript name.
extrasAdditional properties not explicitly defined in the schema.
ProteinVariant$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().