Pseudocigar
Pseudocigar.RdInformation on pseudocigar for a sequence.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
pseudocigar_generation_description: A description of how the pseudocigar information was generated.pseudocigar_seq: The pseudocigar itself.ref_loc: The genomic location the pseudocigar is in reference to.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
pseudocigar_generation_descriptionA description of how the pseudocigar information was generated.
pseudocigar_seqThe pseudocigar itself.
ref_locThe genomic location the pseudocigar is in reference to.
extrasAdditional properties not explicitly defined in the schema.
Methods
Pseudocigar$new()
Create a new instance.
Usage
Pseudocigar$new(
pseudocigar_generation_description = NULL,
pseudocigar_seq = NA_character_,
ref_loc = NULL,
extras = list()
)Pseudocigar$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().