ReactionInfo
ReactionInfo.RdInformation on a panel of targeted amplicon primer pairs.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
panel_targets: A list of the target indexes in the target_info list.reaction_name: A name for this reaction.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
panel_targetsA list of the target indexes in the target_info list.
reaction_nameA name for this reaction.
extrasAdditional properties not explicitly defined in the schema.
Methods
ReactionInfo$new()
Create a new instance.
Usage
ReactionInfo$new(
panel_targets = numeric(),
reaction_name = NA_character_,
extras = list()
)ReactionInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().