RepresentativeMicrohaplotype
RepresentativeMicrohaplotype.RdThe representative sequence for a microhaplotype.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
alt_annotations: A list of additional annotations associated with this microhaplotype, e.g. wildtype.associated_protein_variants: A list of protein variants for this haplotype, e.g. amino acid changes/INDELS.associated_seq_variants: A list of sequence variants for this haplotype, e.g. SNPS, indels.masking: Masking info for the sequence.microhaplotype_name: An optional name for this microhaplotype.pseudocigar: The pseudocigar of the haplotype.quality: The ASCII fastq per base quality score for this sequence, this is optional, must be same length as the sequence.seq: The sequence.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
alt_annotationsA list of additional annotations associated with this microhaplotype, e.g. wildtype.
associated_protein_variantsA list of protein variants for this haplotype, e.g. amino acid changes/INDELS.
associated_seq_variantsA list of sequence variants for this haplotype, e.g. SNPS, indels.
maskingMasking info for the sequence.
microhaplotype_nameAn optional name for this microhaplotype.
pseudocigarThe pseudocigar of the haplotype.
qualityThe ASCII fastq per base quality score for this sequence, this is optional, must be same length as the sequence.
seqThe sequence.
extrasAdditional properties not explicitly defined in the schema.
Methods
RepresentativeMicrohaplotype$new()
Create a new instance.
Usage
RepresentativeMicrohaplotype$new(
alt_annotations = NULL,
associated_protein_variants = NULL,
associated_seq_variants = NULL,
masking = NULL,
microhaplotype_name = NULL,
pseudocigar = NULL,
quality = NULL,
seq = NA_character_,
extras = list()
)Arguments
alt_annotationsA list of additional annotations associated with this microhaplotype, e.g. wildtype.
associated_protein_variantsA list of protein variants for this haplotype, e.g. amino acid changes/INDELS.
associated_seq_variantsA list of sequence variants for this haplotype, e.g. SNPS, indels.
maskingMasking info for the sequence.
microhaplotype_nameAn optional name for this microhaplotype.
pseudocigarThe pseudocigar of the haplotype.
qualityThe ASCII fastq per base quality score for this sequence, this is optional, must be same length as the sequence.
seqThe sequence.
extrasAdditional properties not explicitly defined in the schema.
RepresentativeMicrohaplotype$validate()
Validate the current instance against schema-derived constraints.
RepresentativeMicrohaplotype$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().