RepresentativeMicrohaplotypes
RepresentativeMicrohaplotypes.RdA collection of representative sequences for microhaplotypes for all targets.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
targets: A list of the microhaplotypes for each targets.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
targetsA list of the microhaplotypes for each targets.
extrasAdditional properties not explicitly defined in the schema.
Methods
RepresentativeMicrohaplotypes$new()
Create a new instance.
Usage
RepresentativeMicrohaplotypes$new(targets = list(), extras = list())RepresentativeMicrohaplotypes$validate()
Validate the current instance against schema-derived constraints.
RepresentativeMicrohaplotypes$to_list()
Convert the object to a plain R list using in-memory values.
RepresentativeMicrohaplotypes$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().