RepresentativeMicrohaplotypesForTarget
RepresentativeMicrohaplotypesForTarget.RdA list of the representative sequence for the microhaplotypes for a target.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
mhap_location: A genomic location that was analyzed for this target info, this allows listing location that may be different from the full target location (e.g 1 trimmed off the full length).microhaplotypes: A list of all the microhaplotypes for a target.target_id: The index into the target_info list.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
mhap_locationA genomic location that was analyzed for this target info, this allows listing location that may be different from the full target location (e.g 1 trimmed off the full length).
microhaplotypesA list of all the microhaplotypes for a target.
target_idThe index into the target_info list.
extrasAdditional properties not explicitly defined in the schema.
Methods
RepresentativeMicrohaplotypesForTarget$new()
Create a new instance.
Usage
RepresentativeMicrohaplotypesForTarget$new(
mhap_location = NULL,
microhaplotypes = list(),
target_id = NA_real_,
extras = list()
)Arguments
mhap_locationA genomic location that was analyzed for this target info, this allows listing location that may be different from the full target location (e.g 1 trimmed off the full length).
microhaplotypesA list of all the microhaplotypes for a target.
target_idThe index into the target_info list.
extrasAdditional properties not explicitly defined in the schema.
RepresentativeMicrohaplotypesForTarget$validate()
Validate the current instance against schema-derived constraints.
RepresentativeMicrohaplotypesForTarget$to_list()
Convert the object to a plain R list using in-memory values.
RepresentativeMicrohaplotypesForTarget$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().