TargetInfo
TargetInfo.RdInformation about a specific targeted microhaplotype.
Auto-generated R6 class from JSON Schema.
Format
An R6::R6Class() generator object.
Constructor
new(...) supports the following arguments.
forward_primer: The forward primer for this target.gene_name: An identifier of the gene, if any, is being covered with this targeted.insert_location: The intended genomic location of the insert of the amplicon (the location between the end of the forward primer and the beginning of the reverse primer).markers_of_interest: A list of markers of interest that are covered by this target.reverse_primer: The reverse primer for this target.target_attributes: A list of classification types for this target.target_name: A name for this target.extras: Additional properties not explicitly defined in the schema.
Methods
See inline method documentation for initialize(), validate(), to_list(), to_json_list(), and to_json().
Public fields
forward_primerThe forward primer for this target.
gene_nameAn identifier of the gene, if any, is being covered with this targeted.
insert_locationThe intended genomic location of the insert of the amplicon (the location between the end of the forward primer and the beginning of the reverse primer).
markers_of_interestA list of markers of interest that are covered by this target.
reverse_primerThe reverse primer for this target.
target_attributesA list of classification types for this target.
target_nameA name for this target.
extrasAdditional properties not explicitly defined in the schema.
Methods
TargetInfo$new()
Create a new instance.
Usage
TargetInfo$new(
forward_primer = NULL,
gene_name = NULL,
insert_location = NULL,
markers_of_interest = NULL,
reverse_primer = NULL,
target_attributes = NULL,
target_name = NA_character_,
extras = list()
)Arguments
forward_primerThe forward primer for this target.
gene_nameAn identifier of the gene, if any, is being covered with this targeted.
insert_locationThe intended genomic location of the insert of the amplicon (the location between the end of the forward primer and the beginning of the reverse primer).
markers_of_interestA list of markers of interest that are covered by this target.
reverse_primerThe reverse primer for this target.
target_attributesA list of classification types for this target.
target_nameA name for this target.
extrasAdditional properties not explicitly defined in the schema.
TargetInfo$to_json()
Convert the object to a JSON string.
Arguments
prettyLogical; pretty-print the JSON.
auto_unboxLogical; passed to
jsonlite::toJSON()....Additional arguments passed to
jsonlite::toJSON().