pmotoolsr: Toolkit for working with Portable Microhaplotype Objects (PMOs)
pmotoolsr-package.RdRead, write, validate, process, build, and combine Portable Microhaplotype Object (PMO) files in R. See the README and the function reference for details, and note the 0-based (on disk) to 1-based (in R) index convention.
Author
Maintainer: Nicholas Hathaway nicholas.hathaway@ucsf.edu (ORCID)
Authors:
Nicholas Hathaway nicholas.hathaway@ucsf.edu (ORCID)