Read a PMO object from a file
read_pmo.RdInformation on final microhaplotype results from a targeted amplicon analysis with associated meta data.
Details
Reads a PMO JSON file from disk, including compressed files ending in
.gz, .bz2, or .xz, and parses it into a PMO R6 instance.
Examples
pmo <- read_pmo(
system.file('extdata', 'example_pmo.json.gz', package = 'pmotoolsr'))